@@ -489,7 +489,7 @@ gpk_log_refilter (void)
 	else
 		filter = NULL;
 
-	g_debug ("len=%i", transactions->len);
+	g_debug ("len=%u", transactions->len);
 
 	/* mark the items as not used */
 	treeview = GTK_TREE_VIEW (gtk_builder_get_object (builder, "treeview_simple"));
@@ -565,12 +565,6 @@ gpk_log_entry_filter_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_da
 	return FALSE;
 }
 
-static void
-gpk_log_button_close_cb (GtkWidget *widget, GtkApplication *application)
-{
-	g_application_release (G_APPLICATION (application));
-}
-
 static void
 gpk_log_activate_cb (GtkApplication *application, gpointer user_data)
 {
@@ -595,7 +589,9 @@ gpk_log_startup_cb (GtkApplication *application, gpointer user_data)
 
 	/* get UI */
 	builder = gtk_builder_new ();
-	retval = gtk_builder_add_from_file (builder, GPK_DATA "/gpk-log.ui", &error);
+	retval = gtk_builder_add_from_resource (builder,
+						"/org/gnome/packagekit/gpk-log.ui",
+						&error);
 	if (retval == 0) {
 		g_warning ("failed to load ui: %s", error->message);
 		goto out;
@@ -614,11 +610,6 @@ gpk_log_startup_cb (GtkApplication *application, gpointer user_data)
 		gtk_entry_set_text (GTK_ENTRY(widget), filter);
 	}
 
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
-	g_signal_connect (widget, "clicked",
-			  G_CALLBACK (gpk_log_button_close_cb), application);
-	gtk_widget_grab_default (widget);
-
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_refresh"));
 	g_signal_connect (widget, "clicked", G_CALLBACK (gpk_log_button_refresh_cb), NULL);
 	gtk_widget_hide (widget);
@@ -659,7 +650,7 @@ gpk_log_startup_cb (GtkApplication *application, gpointer user_data)
 
 	/* set the parent window if it is specified */
 	if (xid != 0) {
-		g_debug ("Setting xid %i", xid);
+		g_debug ("Setting xid %u", xid);
 		gpk_window_set_parent_xid (GTK_WINDOW (widget), xid);
 	}
 
