@@ -214,7 +214,7 @@ gpk_misc_enabled_toggled (GtkCellRendererToggle *cell, gchar *path_str, GpkPrefs
 	g_autofree gchar *repo_id = NULL;
 	GtkTreeIter iter;
 	GtkTreeModel *model;
-	g_autofree GtkTreePath *path = gtk_tree_path_new_from_string (path_str);
+	GtkTreePath *path = gtk_tree_path_new_from_string (path_str);
 	GtkTreeView *treeview;
 
 	/* do we have the capability? */
@@ -230,6 +230,7 @@ gpk_misc_enabled_toggled (GtkCellRendererToggle *cell, gchar *path_str, GpkPrefs
 	gtk_tree_model_get (model, &iter,
 			    GPK_COLUMN_ENABLED, &enabled,
 			    GPK_COLUMN_ID, &repo_id, -1);
+	gtk_tree_path_free (path);
 
 	/* do something with the value */
 	enabled ^= 1;
@@ -440,13 +441,6 @@ gpk_prefs_get_properties_cb (GObject *object, GAsyncResult *res, GpkPrefsPrivate
 	}
 }
 
-static void
-gpk_prefs_close_cb (GtkWidget *widget, gpointer data)
-{
-	GpkPrefsPrivate *priv = (GpkPrefsPrivate *) data;
-	g_application_release (G_APPLICATION (priv->application));
-}
-
 static void
 gpk_pack_startup_cb (GtkApplication *application, GpkPrefsPrivate *priv)
 {
@@ -467,16 +461,14 @@ gpk_pack_startup_cb (GtkApplication *application, GpkPrefsPrivate *priv)
 			  G_CALLBACK (gpk_prefs_repo_list_changed_cb), priv);
 
 	/* get UI */
-	retval = gtk_builder_add_from_file (priv->builder, GPK_DATA "/gpk-prefs.ui", &error);
+	retval = gtk_builder_add_from_resource (priv->builder,
+						"/org/gnome/packagekit/gpk-prefs.ui",
+						&error);
 	if (retval == 0) {
 		g_warning ("failed to load ui: %s", error->message);
 		return;
 	}
 
-	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "button_close"));
-	g_signal_connect (widget, "clicked",
-			  G_CALLBACK (gpk_prefs_close_cb), priv);
-
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "checkbutton_detail"));
 	g_settings_bind (priv->settings_gpk,
 			 GPK_SETTINGS_REPO_SHOW_DETAILS,
@@ -543,7 +535,7 @@ gpm_prefs_commandline_cb (GApplication *application,
 
 	/* set the parent window if it is specified */
 	if (xid != 0) {
-		g_debug ("Setting xid %i", xid);
+		g_debug ("Setting xid %u", xid);
 		gpk_window_set_parent_xid (window, xid);
 	}
 	return TRUE;
